local mapMod = foundation.createMod();

mapMod:registerAssetId("height_map.png", "HEIGHT_MAP")
mapMod:registerAssetId("material_mask.png", "MATERIAL_MASK")
mapMod:registerAssetId("coniferous_density.png", "CONIFEROUS_DENSITY_MAP")
mapMod:registerAssetId("deciduous_density.png", "DECIDUOUS_DENSITY_MAP")
mapMod:registerAssetId("berries_density.png", "BERRIES_DENSITY_MAP")
mapMod:registerAssetId("rock_density.png", "ROCK_DENSITY_MAP")
mapMod:registerAssetId("iron_density.png", "IRON_DENSITY_MAP")
mapMod:registerAssetId("fish_density.png", "FISH_DENSITY_MAP")

-- Register Custom Map
mapMod:register({
	DataType = "CUSTOM_MAP",
	Id = "MAP_Obel_1",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = -17,
	MaxHeight = 65,
	VillagePathList = {
		{
			Entrance = { 470, 0, 1000 },
			Exit = { 475, 0, 950 }
		},
		{
			Entrance = { 1000, 0, 15 },
			Exit = { 1000, 0, 15 }
		},
		{
			Entrance = { 700, 0, 1000 },
			Exit = { 500, 0, 1000 }
		},
		{	
			Entrance = { 340, 0, 1000 },
			Exit = { 300, 0, 1000 }
		},
		{	
			Entrance = { 15, 0, 900 },
			Exit = { 15, 0, 500 }
		},
		{	
			Entrance = { 1000, 0, 100 },
			Exit = { 1000, 0, 115 }
		}
	},
	SpawnList = {
		},
	DensitySpawnList = {
		{
			-- Create forest of Deciduous trees and a few smaller Pine trees
			DensityMap = "DECIDUOUS_DENSITY_MAP",
			Density = 0.9,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_TREE_SYCAMORE", "PREFAB_TREE_OAK", "PREFAB_TREE_POPLAR" },
					RandomWeight = .3,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.85,
						Max = 1.15
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				},
				{
					PrefabList = { "PREFAB_TREE_PINE" },
					RandomWeight = 0.9,
					OffsetSizeRange = {
						Min = 0.15,
						Max = 0.45
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.7,
						Max = 1
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
			-- Create forest of Pine trees
			DensityMap = "CONIFEROUS_DENSITY_MAP",
			Density = .7,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_TREE_PINE" },
					RandomWeight = 0.1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.85,
						Max = 1.15
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
		-- Create forest of berry bushes
			DensityMap = "BERRIES_DENSITY_MAP",
			Density = 1,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_RESOURCE_BERRIES" },
					RandomWeight = 0.1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.85,
						Max = 1.15
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					},
				}
			}
		},
		{
		-- Create rock outcrops - stone resource
			DensityMap = "ROCK_DENSITY_MAP",
			Density = 1,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_RESOURCE_ROCK" },
					RandomWeight = 0.1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.85,
						Max = 1.15
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
		-- Create iron outcrops - iron resource
			DensityMap = "IRON_DENSITY_MAP",
			Density = 1,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_RESOURCE_IRON" },
					RandomWeight = 0.1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.85,
						Max = 1.15
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
		-- Create fish shoals
			DensityMap = "FISH_DENSITY_MAP",
			Density = 1,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_RESOURCE_FISH" },
					RandomWeight = 0.1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.85,
						Max = 1.15
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		}
	}
})